pub struct HyperLogLog { /* private fields */ }Expand description
A HyperLogLog counter
Implementations
Sourceimpl HyperLogLog
impl HyperLogLog
Sourcepub fn new_deterministic(error_rate: f64, seed: u128) -> Self
pub fn new_deterministic(error_rate: f64, seed: u128) -> Self
Create a new HyperLogLog counter with the given error rate and seed.
Sourcepub fn new(error_rate: f64) -> Self
pub fn new(error_rate: f64) -> Self
Create a new HyperLogLog counter with the given error rate and a random
seed.
Sourcepub fn new_from_template(hll: &HyperLogLog) -> Self
pub fn new_from_template(hll: &HyperLogLog) -> Self
Create a new HyperLogLog counter with the same parameters as an
existing one.
Sourcepub fn insert_by_hash_value(&mut self, x: u64)
pub fn insert_by_hash_value(&mut self, x: u64)
Insert a new u64 value into the HyperLogLog counter.
Sourcepub fn merge(&mut self, src: &HyperLogLog)
pub fn merge(&mut self, src: &HyperLogLog)
Merge another HyperLogLog counter into the current one.